==> jc-1.4.0.tar.gz: javax/xml/xpath/XPathException.h <==
// public class javax.xml.xpath.XPathException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bf48a3b3cd7f380d javax_xml_xpath_XPathException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_xml_xpath_XPathException_H_
#define _JC_javax_xml_xpath_XPathException_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_xml_xpath_XPathException$sub_refs	_jc_javax_xml_xpath_XPathException$sub_refs;
typedef struct _jc_javax_xml_xpath_XPathException$sub_nonrefs	_jc_javax_xml_xpath_XPathException$sub_nonrefs;
typedef struct _jc_javax_xml_xpath_XPathException$refs	_jc_javax_xml_xpath_XPathException$refs;
typedef struct _jc_javax_xml_xpath_XPathException$nonrefs	_jc_javax_xml_xpath_XPathException$nonrefs;
typedef struct _jc_javax_xml_xpath_XPathException$object	_jc_javax_xml_xpath_XPathException$object;

typedef const struct _jc_javax_xml_xpath_XPathException$vmethods	_jc_javax_xml_xpath_XPathException$vmethods;
typedef const struct _jc_javax_xml_xpath_XPathException$vtable	_jc_javax_xml_xpath_XPathException$vtable;
typedef const struct _jc_javax_xml_xpath_XPathException$vtype	_jc_javax_xml_xpath_XPathException$vtype;

// Constructors
extern void _jc_javax_xml_xpath_XPathException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_xml_xpath_XPathException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_javax_xml_xpath_XPathException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *);
extern void _jc_javax_xml_xpath_XPathException$method$printStackTrace$0c533e6284fdc6db(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *);
extern void _jc_javax_xml_xpath_XPathException$method$printStackTrace$0235c4ad6dac60e9(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_io_PrintStream$object *);
extern void _jc_javax_xml_xpath_XPathException$method$printStackTrace$a53e2b4b86a79644(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_io_PrintWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_xpath_XPathException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_javax_xml_xpath_XPathException$method_info$printStackTrace$0c533e6284fdc6db;
extern _jc_method _jc_javax_xml_xpath_XPathException$method_info$printStackTrace$0235c4ad6dac60e9;
extern _jc_method _jc_javax_xml_xpath_XPathException$method_info$printStackTrace$a53e2b4b86a79644;

// Virtual methods structure
struct _jc_javax_xml_xpath_XPathException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *);
	void	(*printStackTrace$0c533e6284fdc6db)(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *);
	void	(*printStackTrace$0235c4ad6dac60e9)(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_io_PrintStream$object *);
	void	(*printStackTrace$a53e2b4b86a79644)(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_io_PrintWriter$object *);
};

// Vtable
struct _jc_javax_xml_xpath_XPathException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_xpath_XPathException$vmethods	javax_xml_xpath_XPathException;
};

// Vtype
struct _jc_javax_xml_xpath_XPathException$vtype {
	_jc_type			type;
	_jc_javax_xml_xpath_XPathException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathException$sub_refs {
	struct _jc_java_lang_Throwable$object	*cause;
};

// Reference instance fields (object)
struct _jc_javax_xml_xpath_XPathException$refs {
    _jc_javax_xml_xpath_XPathException$sub_refs	javax_xml_xpath_XPathException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_xpath_XPathException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_xpath_XPathException$sub_nonrefs	javax_xml_xpath_XPathException;
};

// Object instance structure
struct _jc_javax_xml_xpath_XPathException$object {
	_jc_javax_xml_xpath_XPathException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_xpath_XPathException$vtype	*vtype;
	_jc_javax_xml_xpath_XPathException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_xpath_XPathException$vtype _jc_javax_xml_xpath_XPathException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_xpath_XPathException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_xpath_XPathException$class_object;

#endif	/* _JC_javax_xml_xpath_XPathException_H_ */

==> jc-1.4.6.tar.gz: javax/xml/xpath/XPathException.h <==
// public class javax.xml.xpath.XPathException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bf48a3b3cd7f380d javax_xml_xpath_XPathException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_xml_xpath_XPathException_H_
#define _JC_javax_xml_xpath_XPathException_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_xml_xpath_XPathException$sub_refs	_jc_javax_xml_xpath_XPathException$sub_refs;
typedef struct _jc_javax_xml_xpath_XPathException$sub_nonrefs	_jc_javax_xml_xpath_XPathException$sub_nonrefs;
typedef struct _jc_javax_xml_xpath_XPathException$refs	_jc_javax_xml_xpath_XPathException$refs;
typedef struct _jc_javax_xml_xpath_XPathException$nonrefs	_jc_javax_xml_xpath_XPathException$nonrefs;
typedef struct _jc_javax_xml_xpath_XPathException$object	_jc_javax_xml_xpath_XPathException$object;

typedef const struct _jc_javax_xml_xpath_XPathException$vmethods	_jc_javax_xml_xpath_XPathException$vmethods;
typedef const struct _jc_javax_xml_xpath_XPathException$vtable	_jc_javax_xml_xpath_XPathException$vtable;
typedef const struct _jc_javax_xml_xpath_XPathException$vtype	_jc_javax_xml_xpath_XPathException$vtype;

// Constructors
extern void _jc_javax_xml_xpath_XPathException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_xpath_XPathException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_javax_xml_xpath_XPathException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_xpath_XPathException$method$printStackTrace$0c533e6284fdc6db(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_xpath_XPathException$method$printStackTrace$0235c4ad6dac60e9(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_xpath_XPathException$method$printStackTrace$a53e2b4b86a79644(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_xpath_XPathException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_javax_xml_xpath_XPathException$method_info$printStackTrace$0c533e6284fdc6db;
extern _jc_method _jc_javax_xml_xpath_XPathException$method_info$printStackTrace$0235c4ad6dac60e9;
extern _jc_method _jc_javax_xml_xpath_XPathException$method_info$printStackTrace$a53e2b4b86a79644;

// Virtual methods structure
struct _jc_javax_xml_xpath_XPathException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$0c533e6284fdc6db)(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$0235c4ad6dac60e9)(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$a53e2b4b86a79644)(_jc_env *, struct _jc_javax_xml_xpath_XPathException$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_xpath_XPathException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_xpath_XPathException$vmethods	javax_xml_xpath_XPathException;
};

// Vtype
struct _jc_javax_xml_xpath_XPathException$vtype {
	_jc_type			type;
	_jc_javax_xml_xpath_XPathException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathException$sub_refs {
	struct _jc_java_lang_Throwable$object	*cause;
};

// Reference instance fields (object)
struct _jc_javax_xml_xpath_XPathException$refs {
    _jc_javax_xml_xpath_XPathException$sub_refs	javax_xml_xpath_XPathException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_xpath_XPathException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_xpath_XPathException$sub_nonrefs	javax_xml_xpath_XPathException;
};

// Object instance structure
struct _jc_javax_xml_xpath_XPathException$object {
	_jc_javax_xml_xpath_XPathException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_xpath_XPathException$vtype	*vtype;
	_jc_javax_xml_xpath_XPathException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_xpath_XPathException$vtype _jc_javax_xml_xpath_XPathException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_xpath_XPathException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_xpath_XPathException$class_object;

#endif	/* _JC_javax_xml_xpath_XPathException_H_ */
